@@ -10,7 +10,7 @@ async fn main() -> Result<()> {
 
     let api = Rest::new(Options::from_env());
 
-    for market in api.request(GetMarkets).await? {
+    for market in api.request(GetMarkets {}).await? {
         println!(
             "Market {} had ${} volume in the last 24 hours.",
             market.name, market.volume_usd24h
