@@ -154,6 +154,11 @@ async fn get_future() {
         .unwrap();
 }
 
+#[tokio::test]
+async fn get_funding_rates() {
+    init_api().await.request(GetFundingRates {}).await.unwrap();
+}
+
 #[tokio::test]
 async fn account_deserialization() {
     // Sanitized response from FTX API.
